Matrix

Struct Matrix 

pub struct Matrix<T> { /* private fields */ }
A Matrix with generic type items. Can be indexed by mat[(row, col)]

Implementations

Source

impl<T> Matrix<T>

pub fn fill(rows: usize, cols: usize, e: T) -> Self
where T: Clone,

Generates a rowsxcols matrix where every element is e

pub fn build<F: FnMut(usize, usize) -> T>( rows: usize, cols: usize, builder_fn: F, ) -> Self

Generates a rowsxcols matrix where every element is obtained by evaluating builder_fn(row, col)

pub fn identity(rows: usize) -> Self
where T: MatrixElement,

Generates a rowsxrows identity matrix (using MatrixElement::zero() and MatrixElement::one())

pub fn from_vec(rows: usize, cols: usize, data: Vec<T>) -> Option<Self>

Generates a rowsxcols matrix with the data specified in data

returns None if data.len() != rows * cols

Source

impl<T: Clone> Matrix<&T>

pub fn cloned(&self) -> Matrix<T>

Clones the elements of a Matrix<&T> and returns a Matrix<T>

Source

impl<T> Matrix<T>

pub fn rows(&self) -> usize

returns the number of rows (the ‘height’) of the matrix

pub fn cols(&self) -> usize

returns the number of columns (the ‘width’) of the matrix

pub fn dim(&self) -> (usize, usize)

returns the number of rows and the number of columns of the matrix (in that order)

pub fn elements(&self) -> usize

returns the total number of elements in the matrix

pub fn split(self) -> (usize, usize, Vec<T>)

splits the struct up into its parts, that is into (rows, columns, data)

pub fn into_some(self) -> Matrix<Option<T>>

Converts a Matrix<T> to a Matrix<Option<T>> by mapping every element e to Some(e)

pub fn get(&self, row: usize, col: usize) -> IndexResult<&T>

get a reference to the item at (row, col)

Errors

Returns an error if the index is out of bounds

pub fn get_mut(&mut self, row: usize, col: usize) -> IndexResult<&mut T>

get a mutable reference to the item at (row, col)

Errors

Returns an error if the index is out of bounds

pub fn replace(&mut self, row: usize, col: usize, val: T) -> IndexResult<T>

get a the item at (row, col) and replace it with val

This works like {let res = self.get(row, col); self.set(row, col, val); res} but you get ownership of the returned value

Errors

Returns an error if the index is out of bounds

pub fn set(&mut self, row: usize, col: usize, val: T) -> IndexResult<()>

set the item at (row, col) to val

Errors

Returns an error if the index is out of bounds

pub fn get_row(&self, row: usize) -> Result<Vec<&T>, IndexOutOfBounds<usize>>

get an entire row of (references of) items

Errors

Returns an error if the row is out of bounds

pub fn get_row_mut( &mut self, row: usize, ) -> Result<Vec<&mut T>, IndexOutOfBounds<usize>>

get an entire row of (mutable references of) items

Errors

Returns an error if the row is out of bounds

pub fn get_col(&self, col: usize) -> Result<Vec<&T>, IndexOutOfBounds<usize>>

get an entire column of (references of) items

Errors

Returns an error if the column is out of bounds

pub fn get_col_mut( &mut self, col: usize, ) -> Result<Vec<&mut T>, IndexOutOfBounds<usize>>

get an entire column of (mutable references of) items

Errors

Returns an error if the column is out of bounds

pub fn map<F: Fn(T) -> U, U>(self, f: F) -> Matrix<U>

Returns a new Matrix that is obtained by applying the given function to each element

pub fn transposed(self) -> Self

Returns the Transpose of this Matrix

pub fn det(self) -> Option<T>
where T: Add<Output = T> + Sub<Output = T> + MatrixElement + Clone + Mul<Output = T>,

Returns the Determinant of this Matrix

pub fn scaled<U: Mul<T, Output = O> + Clone, O>(self, scalar: U) -> Matrix<O>

Multiplies the matrix with a scalar by multiplying each element with the scalar

Source

impl<T> Matrix<Option<T>>

pub fn take(&mut self, row: usize, col: usize) -> IndexResult<Option<T>>

return the value at (row, col), leaving None in its place

Source

impl Matrix<RotmatElement>

pub fn insert_rotation_value<T, O>(self, value: T) -> Matrix<O>
where T: Trig<Output = O> + Clone, O: Neg<Output = O> + Add<Output = O> + Mul<Output = O> + MatrixElement,

Takes a previously generated Rotation Matrix and inserts a specific value into it For f32 and f64, this would be the angle in radians, but for your own type it could be whatever… (it uses the Trig and the MatrixElement traits to get values for sin, -sin, cos, 0 and 1)