Vector

Struct Vector 

pub struct Vector<T> { /* private fields */ }
A Vector with generic type items. Can be indexed by vector[i]

Implementations

Source

impl<T> Vector<T>

pub fn new(coords: Vec<T>) -> Self

Creates a new Vector with the given coordinates

pub fn dim(&self) -> usize

Returns the amount of dimensions the Vector has

pub fn scaled<U, O>(self, scalar: U) -> Vector<O>
where T: Mul<U, Output = O>, U: Clone,

Multiplies the vector with a scalar

pub fn mag_sqr<O>(self) -> O
where T: Mul<Output = O> + Clone, O: Add<Output = O> + MatrixElement,

Returns the square of the Magnitude (also called Norm) of the Vector

pub fn mag<O, U>(self) -> O
where T: Mul<Output = U> + Clone, U: Add<Output = U> + MatrixElement + SquareRootable<Output = O>,

Returns the Magnitude (also called Norm) of the Vector

pub fn dot<U, O: Add<Output = O> + MatrixElement>( self, rhs: Vector<U>, ) -> Result<O, DimensionsDontMatch<usize, usize>>
where T: Mul<U, Output = O>,

Returns the Dot Product of the Vector and rhs

pub fn map<F, U>(self, f: F) -> Vector<U>
where F: Fn(T) -> U,

Applies a function to every element of the vector